@@ -12,8 +12,9 @@ class ProxyManager:
     :param count: int, how many proxies you want to get
     :type count: integer
     """
-    def __init__(self, count):
+    def __init__(self, count, test_url="https://www.google.com"):
         self.count = count
+        self.test_url = test_url
         self.proxies = []
         if count == 1:
             self.proxies = self.get_one_proxy()
@@ -25,7 +26,7 @@ class ProxyManager:
         #     raise ValueError("You can initialize ProxyManager with ProxyManager(count=1) or ProxyManager(count=4)")
     def check_proxy(self, proxy):
         try:
-            req = requests.get('https://www.google.com', proxies=proxy, timeout=5)
+            req = requests.get(self.test_url, proxies=proxy, timeout=5)
             if req.status_code == 200:
                 return True
             else:
